@@ -2,7 +2,11 @@
 ( cd usr/lib ; ln -sf libwiretap.so.0.0.1 libwiretap.so )
 ( cd usr/lib ; rm -rf libwireshark.so.0 )
 ( cd usr/lib ; ln -sf libwireshark.so.0.0.1 libwireshark.so.0 )
+( cd usr/lib ; rm -rf libwsutil.so.0 )
+( cd usr/lib ; ln -sf libwsutil.so.0.0.0 libwsutil.so.0 )
 ( cd usr/lib ; rm -rf libwiretap.so.0 )
 ( cd usr/lib ; ln -sf libwiretap.so.0.0.1 libwiretap.so.0 )
+( cd usr/lib ; rm -rf libwsutil.so )
+( cd usr/lib ; ln -sf libwsutil.so.0.0.0 libwsutil.so )
 ( cd usr/lib ; rm -rf libwireshark.so )
 ( cd usr/lib ; ln -sf libwireshark.so.0.0.1 libwireshark.so )
